emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] 77/255: saner requirement dependency graph


From: Eric Schulte
Subject: [elpa] 77/255: saner requirement dependency graph
Date: Sun, 16 Mar 2014 01:02:23 +0000

eschulte pushed a commit to branch go
in repository elpa.

commit 947bec9f675cfe40275d0717921a7732a1b6ce28
Author: Eric Schulte <address@hidden>
Date:   Tue May 22 18:32:21 2012 -0400

    saner requirement dependency graph
---
 sgf-board.el |    2 +-
 sgf-gnugo.el |    1 +
 sgf-gtp.el   |    4 ++--
 sgf-igs.el   |    6 +++++-
 sgf-trans.el |    4 +---
 sgf2el.el    |    2 +-
 6 files changed, 11 insertions(+), 8 deletions(-)

diff --git a/sgf-board.el b/sgf-board.el
index 3c052b5..72f2f99 100644
--- a/sgf-board.el
+++ b/sgf-board.el
@@ -26,8 +26,8 @@
 ;; Boston, MA 02110-1301, USA.
 
 ;;; Code:
+(require 'sgf-util)
 (require 'sgf2el)
-(eval-when-compile (require 'cl))
 
 
 ;;; Visualization
diff --git a/sgf-gnugo.el b/sgf-gnugo.el
index 0673f30..f713c48 100644
--- a/sgf-gnugo.el
+++ b/sgf-gnugo.el
@@ -30,6 +30,7 @@
 ;; Interaction with gnugo
 
 ;;; CODE:
+(require 'sgf-util)
 (require 'comint)
 
 (defun sgf-gnugo-gtp-commands ()
diff --git a/sgf-igs.el b/sgf-igs.el
index 52d826b..0fa20a0 100644
--- a/sgf-igs.el
+++ b/sgf-igs.el
@@ -1,4 +1,4 @@
-;;; sgf-igs.el --- translate between sgf and GTP
+;;; sgf-igs.el --- IGS backend for sgf-trans
 
 ;; Copyright (C) 2012 Eric Schulte <address@hidden>
 
@@ -30,3 +30,7 @@
 ;; http://www.pandanet.co.jp/English/commands/term/Summary.html
 
 ;; Code:
+(require 'sgf-util)
+(require 'sgf-trans)
+
+(provide 'sgf-igs)
diff --git a/sgf-trans.el b/sgf-trans.el
index 6cda9b0..9b73fb5 100644
--- a/sgf-trans.el
+++ b/sgf-trans.el
@@ -34,9 +34,7 @@
 ;; - the IGS protocol
 
 ;;; Code:
-(require 'sgf2el)
-(require 'sgf-board)
-(eval-when-compile (require 'cl))
+(require 'sgf-util)
 
 ;; TODO: API, and how functions may implement it
 
diff --git a/sgf2el.el b/sgf2el.el
index 0727cff..401ed56 100644
--- a/sgf2el.el
+++ b/sgf2el.el
@@ -26,7 +26,7 @@
 ;; Boston, MA 02110-1301, USA.
 
 ;;; Code:
-(eval-when-compile (require 'cl))
+(require 'sgf-util)
 
 (defvar prop-re
   "\\([[:alpha:]]+\\)\\(\\(\\[\\]\\|[[:space:]]*\\[[^\000]*?[^\\]\\]\\)+\\)")



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/sgf-gtp.el b/sgf-gtp.el
index 4371610..7c9d0b7 100644
--- a/sgf-gtp.el
+++ b/sgf-gtp.el
@@ -1,4 +1,4 @@
 ;;; sgf-gtp.el --- translate between sgf and GTP
 
 ;; Copyright (C) 2008 2012 Eric Schulte <address@hidden>
 
@@ -32,8 +32,8 @@
 ;; The GMP command set may be implemented as an extension.
 
 ;; Code:
-(require 'cl)
 (require 'sgf-util)
+(require 'sgf-trans)
 
 (defun sgf-gtp-char-to-pos (char)
   (flet ((err () (error "sgf-gtp: invalid char %s" char)))
@@ -1,4 +1,4 @@
-;;; sgf-gtp.el --- translate between sgf and GTP
+;;; sgf-gtp.el --- GTP backend for sgf-trans
 
 ;; Copyright (C) 2008 2012 Eric Schulte <address@hidden>